@@ -40,17 +40,19 @@ class MysqlHelper(Singleton):
         else:
             Param = None
         if isinstance(Param, dict):
+            self.Log.debug(sql % Param)
             return cursor.execute(sql, Param)
         elif isinstance(Param, tuple):
+            self.Log.debug(sql % Param)
             return cursor.execute(sql % Param)
         else:
+            self.Log.debug(sql)
             return cursor.execute(sql)
 
     def Query(self, sql, *Param):
         try:
             self.Log.debug(sql)
             conn, cursor = self.createConn()
-            # print(Param)
             self.executeParam(cursor, sql, Param)
             result = cursor.fetchall()
             cursor.close()
@@ -64,9 +66,9 @@ class MysqlHelper(Singleton):
                 if flag:
                     return result
                 else:
-                    return None
+                    return []
             else:
-                return None
+                return []
         except Exception as e:
             self.Log.error(e.args[:])
             raise Exception(e.args[:])
